.. _module_hydra_core_propertyhead:

propertyhead
============

This sections contains module documentation of propertyhead module.

propertyhead
^^^^^^^^^^^^

Method provides class PropertyHead with various hydratk (from head modules) properties.
Unit tests available at hydratk/core/propertyhead/01_methods_ut.jedi

**Properties (Getters)** :

* current_async_ticket_id - returns _current_async_ticket_id
* async_fn_tickets - return _async_fn_tickets
* fn_cb_shared - returns _fn_cb_shared
* cbm - returns _cbm
* cli_cmdopt_profile - returns _opt_profile
* cfg - returns _config
* debug - returns _debug
* debug_level - returns _debug_level
* ext_cfg - returns _config for given extension
* lang - returns _language
* runlevel - returns _runlevel
* run_mode - returns _run_mode

**Properties (Setters)** :

* async_fn_tickets - sets _async_fn_tickets
* fn_cb_shared - sets _fn_cb_shared
* lang - sets _language
* run_mode - sets _run_mode